@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
+# Copyright (c) 2020-2023 Julian Heinovski <heinovski@ccs-labs.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,6 +17,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
+import sys
 import time
 from typing import TYPE_CHECKING
 
@@ -38,6 +39,7 @@ def record_general_data_begin(basename: str, simulator: 'Simulator'):
     with open(f'{basename}_general.out', 'w') as f:
         f.write(f"simulation start: {time.asctime(time.localtime(time.time()))}\n")
         f.write(f"version: {__version__}\n")
+        f.write(f"command:\n{' '.join(sys.argv)}\n")
         f.write(f"parameters:\n{str(simulator)}\n")
 
 
@@ -48,6 +50,11 @@ def record_general_data_end(basename: str, simulator: 'Simulator'):
     with open(f'{basename}_general.out', 'a') as f:
         f.write(f"simulation end: {time.asctime(time.localtime(time.time()))}\n")
         f.write(f"average number of vehicles: {simulator._avg_number_vehicles}\n")
+        f.write(f"average number of vehicles in spawn queue: {simulator._avg_number_vehicles_queue}\n")
+        f.write(f"average number of vehicles spawned: {simulator._avg_number_vehicles_spawned}\n")
+        f.write(f"average number of vehicles arrived: {simulator._avg_number_vehicles_arrived}\n")
+        f.write(f"average vehicle speed: {simulator._avg_vehicle_speed}\n")
+        f.write(f"average number of vehicles braking rough: {simulator._avg_number_vehicles_braking_rough}\n")
 
 
 def initialize_vehicle_trips(basename: str):
@@ -362,6 +369,7 @@ def initialize_vehicle_traces(basename: str):
             "blocked,"
             "duration,"
             "routeLength,"
+            "timeLoss,"
             "desiredSpeed,"
             "cfTargetSpeed,"
             "cfModel,"
@@ -384,6 +392,7 @@ def record_vehicle_trace(basename: str, step: int, vehicle: 'Vehicle'):
             f"{vehicle._blocked_front},"
             f"{vehicle.travel_time},"
             f"{vehicle.travel_distance},"
+            f"{vehicle._time_loss},"
             f"{vehicle.desired_speed},"  # use potential platoon desired driving speed
             f"{vehicle._cf_target_speed},"
             f"{vehicle._cf_model.name},"
@@ -409,7 +418,7 @@ def initialize_vehicle_changes(basename: str):
 
 def record_vehicle_change(
     basename: str,
-    step: int,
+    step: float,
     vid: int,
     position: float,
     speed: float,
@@ -446,7 +455,7 @@ def initialize_emission_traces(basename: str):
         )
 
 
-def record_emission_trace_prefix(basename: str, step: int, vid: int):
+def record_emission_trace_prefix(basename: str, step: float, vid: int):
     assert basename
     with open(f'{basename}_emission_traces.csv', 'a') as f:
         f.write(
@@ -477,12 +486,14 @@ def initialize_vehicle_platoon_traces(basename: str):
             "id,"
             "platoon,"
             "platoonRole,"
-            "platoonPosition"
+            "platoonMemberPosition,"
+            "platoonDesiredSpeed,"
+            "platoonSpeed"
             "\n"
         )
 
 
-def record_vehicle_platoon_trace(basename: str, step: int, vehicle: 'PlatooningVehicle'):
+def record_vehicle_platoon_trace(basename: str, step: float, vehicle: 'PlatooningVehicle'):
     assert basename
     from .platooning_vehicle import PlatooningVehicle
     assert isinstance(vehicle, PlatooningVehicle)
@@ -492,7 +503,9 @@ def record_vehicle_platoon_trace(basename: str, step: int, vehicle: 'PlatooningV
             f"{vehicle._vid},"
             f"{vehicle._platoon.platoon_id},"
             f"{vehicle._platoon_role.name},"
-            f"{vehicle._platoon.get_member_index(vehicle)}"
+            f"{vehicle._platoon.get_member_index(vehicle)},"
+            f"{vehicle._platoon.desired_speed},"
+            f"{vehicle._platoon.speed}"
             "\n"
         )
 
@@ -515,7 +528,7 @@ def initialize_platoon_traces(basename: str):
         )
 
 
-def record_platoon_trace(basename: str, step: int, vehicle: 'PlatooningVehicle'):
+def record_platoon_trace(basename: str, step: float, vehicle: 'PlatooningVehicle'):
     assert basename
     from .platooning_vehicle import PlatooningVehicle
     assert isinstance(vehicle, PlatooningVehicle)
@@ -552,7 +565,7 @@ def initialize_platoon_changes(basename: str):
 
 def record_platoon_change(
     basename: str,
-    step: int,
+    step: float,
     leader: 'PlatooningVehicle',
     source_lane: int,
     target_lane: int,
@@ -594,7 +607,7 @@ def initialize_vehicle_platoon_changes(basename: str):
 
 def record_vehicle_platoon_change(
     basename: str,
-    step: int,
+    step: float,
     member: 'PlatooningVehicle',
     source_lane: int,
     target_lane: int,
@@ -626,19 +639,23 @@ def initialize_simulation_trace(basename: str):
             "vehiclesInSpawnQueue,"
             "vehiclesSpawned,"
             "vehiclesArrived,"
-            "executionTime"
+            "executionTime,"
+            "averageVehicleSpeed,"
+            "vehiclesBrakingRough"
             "\n"
         )
 
 
 def record_simulation_trace(
         basename: str,
-        step: int,
+        step: float,
         vehicles_in_simulator: int,
         vehicles_in_queue: int,
         vehicles_spawned: int,
         vehicles_arrived: int,
-        runtime: float
+        runtime: float,
+        average_vehicle_speed: float,
+        vehicles_braking_rough: int,
 ):
     assert basename
     with open(f'{basename}_simulation_trace.csv', 'a') as f:
@@ -648,6 +665,50 @@ def record_simulation_trace(
             f"{vehicles_in_queue},"
             f"{vehicles_spawned},"
             f"{vehicles_arrived},"
-            f"{runtime}"
+            f"{runtime},"
+            f"{average_vehicle_speed},"
+            f"{vehicles_braking_rough}"
+            "\n"
+        )
+
+
+def initialize_vehicle_teleports(basename: str):
+    assert basename
+    with open(f'{basename}_vehicle_teleports.csv', 'w') as f:
+        f.write(
+            "step,"
+            "id,"
+            "oldPosition,"
+            "oldLane,"
+            "oldSpeed,"
+            "newPosition,"
+            "newLane,"
+            "newSpeed"
+            "\n"
+        )
+
+
+def record_vehicle_teleport(
+    basename: str,
+    step: float,
+    vid: int,
+    old_position: float,
+    old_lane: int,
+    old_speed: float,
+    new_position: float,
+    new_lane: int,
+    new_speed: float,
+):
+    assert basename
+    with open(f'{basename}_vehicle_teleports.csv', 'a') as f:
+        f.write(
+            f"{step},"
+            f"{vid},"
+            f"{old_position},"
+            f"{old_lane},"
+            f"{old_speed},"
+            f"{new_position},"
+            f"{new_lane},"
+            f"{new_speed}"
             "\n"
         )
