@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
+# Copyright (c) 2020-2023 Julian Heinovski <heinovski@ccs-labs.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -47,7 +47,7 @@ def round_to_next_base(x: float, base: float) -> float:
 def rgb2hex(rgb: tuple) -> str:
     assert len(rgb) == 3
     for c in rgb:
-        assert (type(c) == int and 0 <= c <= 255)
+        assert type(c) == int and 0 <= c <= 255
 
     return '#' + ''.join(f'{i:02X}' for i in rgb)
 
@@ -61,7 +61,7 @@ def hex2rgb(hex: str) -> tuple:
 
 def assert_index_equal(a, b):
     """
-    Ensure the indeces of two Sequences/DataFrames are equal.
+    Ensure the indices of two Sequences/DataFrames are equal.
 
     Parameters
     ----------
@@ -69,6 +69,7 @@ def assert_index_equal(a, b):
     b : pandas.Sequence / pandas.DataFrame
     """
 
+    # TODO use pandas.testing.assert_index_equal?
     assert list(a.index) == list(b.index)
 
 
@@ -136,13 +137,13 @@ def speed2acceleration(speed_from: float, speed_to: float, time_interval: float
 
 def addLoggingLevel(levelName, levelNum, methodName=None):
     """
-    https://stackoverflow.com/a/35804945.
-
     Comprehensively adds a new logging level to the `logging` module and the currently configured logging class.
 
     `levelName` becomes an attribute of the `logging` module with the value `levelNum`. `methodName` becomes a convenience method for both `logging` itself and the class returned by `logging.getLoggerClass()` (usually just `logging.Logger`). If `methodName` is not specified, `levelName.lower()` is used.
 
-    To avoid accidental clobberings of existing attributes, this method will raise an `AttributeError` if the level name is already an attribute of the `logging` module or if the method name is already present
+    To avoid accidental clobberings of existing attributes, this method will raise an `AttributeError` if the level name is already an attribute of the `logging` module or if the method name is already present.
+
+    Taken from https://stackoverflow.com/a/35804945.
     """
 
     if not methodName:
