@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2020-2022 Julian Heinovski <heinovski@ccs-labs.org>
+# Copyright (c) 2020-2023 Julian Heinovski <heinovski@ccs-labs.org>
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -20,7 +20,6 @@
 import logging
 from typing import TYPE_CHECKING
 
-from .message import Message
 from .mobility import CF_Model
 from .statistics import (
     record_emission_trace_prefix,
@@ -65,8 +64,8 @@ class Vehicle:
             desired_speed: float,
             depart_lane: int,
             depart_speed: float,
-            depart_time: int,
-            depart_delay: int,
+            depart_time: float,
+            depart_delay: float,
             communication_range: int,
             pre_filled: bool = False,
     ):
@@ -82,18 +81,18 @@ class Vehicle:
         vehicle_type : VehicleType
             The vehicle type of the vehicle
         depart_position : int
-            The depart position of the vehicle
+            The departure position of the vehicle
         arrival_position : int
             The arrival position of the vehicle
         desired_speed : float
             The desired driving speed of the vehicle
         depart_lane : int
-            The depart lane of the vehicle
+            The departure lane of the vehicle
         depart_speed : float
-            The depart speed of the vehicle
-        depart_time : int
-            The depart time of the vehicle
-        depart_delay : int
+            The departure speed of the vehicle
+        depart_time : float
+            The actual departure time of the vehicle
+        depart_delay : float
             The time the vehicle had to wait before starting its trip
         communication_range : int
             The maximum communication range of the vehicle
@@ -113,7 +112,7 @@ class Vehicle:
         self._depart_lane = depart_lane  # the departure lane of the vehicle
         self._depart_speed = depart_speed  # the departure speed of the vehicle
         self._depart_time = depart_time  # the departure time of the vehicle
-        self._depart_delay = depart_delay  # the depart delay of the vehicle
+        self._depart_delay = depart_delay  # the departure delay of the vehicle
         self._pre_filled = pre_filled  # whether this vehicle was pre-filled
         # vehicle details
         self._position = self._depart_position  # the current position of the vehicle
@@ -129,14 +128,14 @@ class Vehicle:
         self._communication_range = communication_range  # the maximum communication range between two vehicles
 
         # statistics
-        self._time_loss = 0
+        self._time_loss = 0  # SUMO: "The time lost due to driving below the ideal speed."
         self._emissions = {
-            'CO': 0,  # the total CO (Kohlenmonoxid) emission in mg
-            'CO2': 0,  # the total CO2 (Kohlendioxid) emission in mg
-            'HC': 0,  # the total HC (Kohlenwasserstoffe) emission in mg
-            'NOx': 0,  # the total NOx (Stickoxide) emission in mg
-            'PMx': 0,  # the total PM (Partikel) emission in mg
-            'fuel': 0,  # the total mKr (Kraftstoffverbrauch) emission in mg
+            "CO": 0,  # the total carbon monoxide (CO) emission in mg
+            "CO2": 0,  # the total carbon dioxide (CO2) emission in mg
+            "HC": 0,  # the total hydro carbon (HC) emission in mg
+            "NOx": 0,  # the total nitrogen oxides (NO and NO2) emission in mg
+            "PMx": 0,  # the total fine-particle (PMx) emission in mg
+            "fuel": 0,  # the total fuel consumption emission in ml
         }
 
         # gui properties
@@ -233,7 +232,7 @@ class Vehicle:
     @property
     def depart_position(self) -> int:
         """
-        Return the depart position of the vehicle.
+        Return the departure position of the vehicle.
         """
 
         return self._depart_position
@@ -269,7 +268,7 @@ class Vehicle:
     @property
     def depart_lane(self) -> int:
         """
-        Return the depart lane of the vehicle.
+        Return the departure lane of the vehicle.
         """
 
         return self._depart_lane
@@ -277,15 +276,15 @@ class Vehicle:
     @property
     def depart_speed(self) -> float:
         """
-        Return the depart speed of the vehicle.
+        Return the departure speed of the vehicle.
         """
 
         return self._depart_speed
 
     @property
-    def depart_time(self) -> int:
+    def depart_time(self) -> float:
         """
-        Return the depart time of the vehicle.
+        Return the departure time of the vehicle.
         """
 
         return self._depart_time
@@ -385,13 +384,13 @@ class Vehicle:
         if self._simulator._actions:
             self._action(step)
 
-    def _action(self, step: int):
+    def _action(self, step: float):
         """
         Triggers specific actions of a vehicle.
 
         Parameters
         ----------
-        step : int
+        step : float
             The current simulation step
         """
 
@@ -432,13 +431,16 @@ class Vehicle:
         # calculate time loss
         # SUMO: "The time lost due to driving below the ideal speed."
         # can also use higher layer desired speed
-        # FIXME: should this the cf target speed?
-        if self._speed < self.desired_speed:
+        if self._speed < self._cf_target_speed:
             self._time_loss += self._simulator.step_length
 
         if self._simulator._record_vehicle_traces:
             # mobility/trip statistics
-            record_vehicle_trace(basename=self._simulator._result_base_filename, step=self._simulator.step, vehicle=self)
+            record_vehicle_trace(
+                basename=self._simulator._result_base_filename,
+                step=self._simulator.step,
+                vehicle=self,
+            )
 
         self._calculate_emissions()
 
@@ -469,17 +471,20 @@ class Vehicle:
         ec = self._vehicle_type.emission_class
         for variable in self._emissions.keys():
             scale = 3.6
-            if variable == 'fuel':
+            if variable == "fuel":
                 if ec.is_diesel:
                     scale *= 836.0
                 else:
                     scale *= 742.0
-            value = (self._calculate_emission(
-                self._acceleration,
-                self._speed,
-                ec.emission_factors[variable],
-                scale
-            ) * self._simulator.step_length)
+            value = (
+                self._calculate_emission(
+                    self._acceleration,
+                    self._speed,
+                    ec.emission_factors[variable],
+                    scale,
+                )
+                * self._simulator.step_length
+            )
             self._emissions[variable] += value
 
             if self._simulator._record_emission_traces:
@@ -506,7 +511,18 @@ class Vehicle:
 
         if a < 0:
             return 0
-        return max((f[0] + f[1] * a * v + f[2] * a * a * v + f[3] * v + f[4] * v * v + f[5] * v * v * v) / scale, 0.0)
+        return max(
+            (
+                f[0]
+                + f[1] * a * v
+                + f[2] * a * a * v
+                + f[3] * v
+                + f[4] * v * v
+                + f[5] * v * v * v
+            )
+            / scale,
+            0.0,
+        )
 
     def finish(self):
         """
@@ -545,9 +561,8 @@ class Vehicle:
             # this should only be the case for pre-filled vehicles or if started as platoon
             # TODO use pre_filled flag
             assert (
-                (self._simulator._record_prefilled and self._depart_time == -1)
-                or self._simulator._start_as_platoon
-            )
+                self._simulator._record_prefilled and self._depart_time == -1
+            ) or self._simulator._start_as_platoon
 
         assert travel_time_ratio >= 0
         assert average_driving_speed >= 0
@@ -579,94 +594,3 @@ class Vehicle:
         self_dict = self.__dict__.copy()
         self_dict.update({'_vehicle_type': str(self._vehicle_type)})  # use str representation of vehicle type
         return str(self_dict)
-
-    def _transmit(self, destination_vid: int, message: Message) -> bool:
-        """
-        Transmit a message of type Message.
-
-        Messages are in general not used at the moment.
-
-        Parameters
-        ----------
-        destination_vid : int
-            The id of the destination vehicle
-        message : Message
-            The message to transmit
-
-        THIS IS DEPRECATED AT THE MOMENT!!!
-        """
-
-        if isinstance(message, Message):
-            if destination_vid == -1:
-                # TODO do we really want access the private field of the vehicles here (i.e., within this class)?
-                for vehicle in self._simulator._vehicles.values():
-                    vehicle.receive(message)
-            else:
-                # TODO do we really want access the private field of the vehicles here (i.e., within this class)?
-                self._simulator._vehicles[destination_vid].receive(message)
-
-            return True  # this should always be true, at least currently
-        raise RuntimeError("Message is not an instance of type Message")
-
-    def receive(self, message) -> bool:
-        """
-        Receives a message of arbitrary type.
-
-        Messages are in general not used at the moment.
-
-        Parameters
-        ----------
-        message :
-            The message to be received
-
-        Raises
-        ------
-        RuntimeError
-            If the message to be received is not an instance of the Message type.
-
-        THIS IS DEPRECATED AT THE MOMENT!!!
-        """
-
-        if self._simulator.step < self._depart_time:
-            # we cannot receive anything since we did not start yet
-            return False
-        if isinstance(message, Message):
-            if message.destination == self._vid or message.destination == -1:
-                self._handle_message(message)
-            # we cannot receive this message since it was not for us
-            return False
-        raise RuntimeError("Message is not an instance of type Message")
-
-    def _handle_message(self, message: Message):
-        """
-        Handle a message of arbitrary type Message.
-
-        Messages are in general not used at the moment.
-
-        Parameters
-        ----------
-        message : Message
-            The message to be handled
-
-        THIS IS DEPRECATED AT THE MOMENT!!!
-        """
-
-        func = self.__class__.__dict__.get('_receive_' + message.__class__.__name__,
-                                           lambda v, m: print("cannot handle message", m))
-        return func(self, message)
-
-    def _receive_Message(self, message: Message):
-        """
-        Handle a message of the specific type Message.
-
-        Messages are in general not used at the moment.
-
-        Parameters
-        ----------
-        message : Message
-            The message to be received
-
-        THIS IS DEPRECATED AT THE MOMENT!!!
-        """
-
-        LOG.warning(f"{self._vid} received non-sense message {message}")
